
/* contest: 2002 ACM CEPC, Warsaw
 * problem: "One way traffic"
 * solution output checker
 * author: Marcin Stefaniak 
 * date: 21.10.2002
 */

/*
	arg1 - input file
	arg2 - contestant output file
	arg3 - good output file (hint file)

	program writes on std out:
	1st line - one uppercase word
		OK
		WRONG
	2nd line - error description

*/

using namespace std;
 
#include<iostream>
#include<fstream>
#include<vector>

#define REP(i, n) for(int i=0;i<(n);i++)
#define VAR(zm, wyr) typeof((wyr)) zm = (wyr)
#define FOREACH(it, kol) for(VAR(it, (kol).begin()); it!=(kol).end(); ++it)

const int MAXN = 2000;

class Traffic {
	public:

	int n, m;
	vector<bool> *e;	
	
	Traffic(int _n, int _m) : n(_n), m(_m) {
		e = new vector<bool> [n+1];
		REP(i, 1+n) e[0].push_back(false);
		REP(i, n) e[i+1] = e[0];	
	}

	void addOneWay(int a, int b) { e[a][b] = true; }
	void addTwoWay(int a, int b) { e[a][b] = e[b][a] = true; }

	bool connected(int a, int b) { return e[a][b]; }
	int wayKind(int a, int b) { return e[a][b] ? (e[b][a] ? 2 : 1) : 0; }


	void dfs(int a, bool visited[]) {
		visited[a] = true;
		for(int b=1; b<=n; b++) 
			if (!visited[b] && connected(a, b))
				dfs(b, visited);
	}

	void dfs_rev(int a, bool visited[]) {
		visited[a] = true;
		for(int b=1; b<=n; b++) 
			if (!visited[b] && connected(b, a))
				dfs_rev(b, visited);
	}

	int noOf2way() {
		int cnt=0;
		for(int a=1;a<=n;a++) for(int b=1;b<a;b++)
			if (e[a][b] && e[b][a]) cnt++;
		return cnt;	
	}
	
	void read_output(istream& ist) {
		int m2 = noOf2way(), a, b, c;
		REP(i, m2) {
			ist >> a >> b >> c;
			if (!ist) {
				cout << "WRONG\nBad output: unexpected eof / file not found\n";
				exit(1);
			}
			if (a<1||a>n||b<1||b>n||c<1||c>2) {
				cout << "WRONG\nBad output: out of range\n";
				exit(1);
			}
			if (!(e[a][b] && e[b][a])) {
				cout << "WRONG\nBad output: not a 2way street or duplicated output " << a << " " <<b << endl;
				exit(1);
			}
			if (c==1) { 
				e[b][a] = false;
			//	cerr << a << " " << b << " " << c << "\n";
			}
		}	
		char ch;
		ist >> ch;
		if (ist) {
			cout << "WRONG\nBad output: eof expected\n";
			exit(1);
		}
	}
	

};

Traffic* read_data(istream& cin) {
	int n, m, a, b, c;
	cin	>> n >> m;
	if (!cin) {
		cerr << "\nBad input! eof, line = 1\n";
		exit(1);
	}
	if (n > MAXN) {
		cerr << "\nBad input! n > MAXN, line = 1\n";
		exit(1);
	}
	if (2*m > n*n-n) {
		cerr << "\nBad input! 2*m > n*n, line = 1\n";
		exit(1);
	}
	
	Traffic *traffic = new Traffic(n, m);
	REP(i, m) {
		cin >> a >> b >> c;
		if (!cin) {
			cerr << "\nBad input! eof, line = " << i+2 << "\n";
			exit(1);
		}
		if (a<1||a>n||b<1||b>n) {
			cerr << "\nBad input! line = "<< i+2 <<", a,b out of range\n";
			exit(1);
		}
		if (traffic->connected(a, b) || traffic->connected(b, a)) {
			cerr << "\nBad input! line = "<< i+2 <<", already connected\n";
			exit(1);
		}
		if (c==1)	traffic->addOneWay(a, b);
		else if (c==2) traffic->addTwoWay(a, b);
		else {
			cerr << "\nBad input! line = "<< i+2 <<", c!=1,2\n";
			exit(1);
		}
	}
	return traffic;
}

bool visited[MAXN+1];

void check_connected(Traffic *traffic) {
	// enough to check if there is a connection from and to one vertex

	int n = traffic->n;
	REP(i, n+1) visited[i] = false;
	traffic->dfs(1, visited);
	for(int i=1; i<=n; i++) if (!visited[i]) {
		cerr << "WRONG\nno connection from 1 to " << i << endl;
		exit(1);
	}

	REP(i, n+1) visited[i] = false;
	traffic->dfs_rev(1, visited);
	for(int i=1; i<=n; i++) if (!visited[i]) {
		cout << "WRONG\nno connection to 1 from " << i << endl;
		exit(1);
	}
	
}


int read_noOf2way(istream& ist, int m) {
	int cnt = 0, a, b, c;
	REP(i, m) {
		ist >> a >> b >> c;
		if (c==2) cnt++;
	}
	return cnt;
}

int main(int argc, char* argv[]) {

	ifstream inputfile(argv[1]);
	ifstream outputfile(argv[2]);
	ifstream hintfile(argv[3]);
	Traffic *traffic = read_data(inputfile);
		
	int limit_2way = read_noOf2way(hintfile, traffic->noOf2way());
	
	traffic->read_output(outputfile);
	
	check_connected(traffic);

	int n2way = traffic->noOf2way();

	if (n2way > limit_2way) {
		cout << "WRONG\ntoo many 2way streets, " << n2way << "/" << limit_2way << "\n"; exit(1);
	}
	
	cout << "OK\n";
	return 0;
}
