
/* contest: 2002 ACM CEPC, Warsaw
 * problem: "One way traffic"
 * special input generator
 * author: Marcin Stefaniak 
 * date: 21.10.2002
 */

using namespace std;
 
#include<iostream>
#include<fstream>
#include<vector>
#include<cstdlib>
#include<algorithm>

#include <stdio.h>

#define REP(i, n) for(int i=0;i<(n);i++)
#define FOR(i, a, b) for(int i=(a);i<=(b);i++)
#define VAR(zm, wyr) typeof((wyr)) zm = (wyr)
#define FOREACH(it, kol) for(VAR(it, (kol).begin()); it!=(kol).end(); ++it)

const int MAXN = 2000;

ofstream *out;

int n, m;

bool e[1+MAXN][1+MAXN];

bool visited[MAXN+1];

void dfs(int a) {
	visited[a] = true;
	FOR(b,1,n) if (!visited[b] && e[a][b]) dfs(b);
}

void dfs_rev(int a) {
	visited[a] = true;
	FOR(b,1,n) if (!visited[b] && e[b][a]) dfs_rev(b);
}

bool check_connected() {
	// enough to check if there is a connection from vertex 1 and to vertex 1
	FOR(i,1,n) visited[i] = false;
	dfs(1);
	FOR(i,1,n) if (!visited[i]) return false;

	FOR(i,1,n) visited[i] = false;
	dfs_rev(1);
	FOR(i,1,n) if (!visited[i]) return false;
	
	return true;
}

int count_m() {
	int cnt=0;
	FOR(a,1,n) FOR(b,1,a-1) if (e[a][b] || e[b][a]) cnt++;
	return cnt;
}

int perm[MAXN+1];

struct Edge { short a,b; char c; Edge() {} Edge(short _a, short _b, char _c):a(_a),b(_b),c(_c){} };

void write_output(bool randomized) {
	// writing output (a bit randomly)
//	cerr << "writing...";

	if (randomized) FOR(a,1,n) {
		int b = 1+random()%a;
		perm[a] = perm[b]; perm[b] = a;
	} else
		FOR(a,1,n) perm[a]=a; // no random permutation

	m = count_m();

	*out << n << " " << m << endl;

	vector<Edge> edges;

	FOR(a,1,n) FOR(b,1,n) if (a!=b && e[a][b]) {
		if (!e[b][a]) 
			edges.push_back(Edge(a,b,1)); 
		else if (a<b) {
			if (!randomized || random()%2)
				edges.push_back(Edge(a,b,2));
			else	
				edges.push_back(Edge(b,a,2));
		}
		if (randomized) swap(edges[edges.size()-1], edges[random()%edges.size()]);
	}

	FOREACH(it, edges) *out << perm[it->a] <<" " << perm[it->b] << " " << (int)it->c << endl;

}

void w1(int a, int b) { 
	if (a==b || a<1||a>n||b<1||b>n) cerr << "oops...w1\n";
	e[a][b] = true; 
}
void w2(int a, int b) { 
	if (a==b || a<1||a>n||b<1||b>n) cerr << "oops...w2\n";
	e[a][b] = e[b][a] = true; 
}

void make_test0() {
	// przykladowy
	n = 4; m = 4;
	w2(1,2); w1(2, 3); w2(3, 4); w1(4,2);
}

void make_test1() {
	// jeden most
	n = 2; m = 1;
	w2(1, 2);
}

void make_test2() {
	// drzewo binarne
	n = 2000; m = 1999;
	FOR(a,2,n) w2(a, a/2);
}

void make_test3() {
	// jeden cykl
	n = 2000; m = 2000;
	FOR(a,2,n) w2(a, a-1); 
	w1(n, 1);
}

void make_test4() {
	// maly graf ale calkiem pelny 
	n = 200; 
	FOR(a,1,n) FOR(b,1,a-1) w2(a,b);
}

void make_test5() {
	// duzy graf, rozpiety na drzewie binarnym, krawedzi jest liniowo,
	// z kazdego v=2^k*i+j idzie w tyl do i
	n = 2000;
	FOR(a,2,n) w2(a, a/2);
	FOR(a,2,n) { int b = a; while (b%2==0) b/=2; 
		if (b==a || b==a/2) continue;
		w1(a, b);
	}
	  
}

void component(int d, int g, int nasycenie, int zwrot) {
	// robi skladowa oparta na liscie d..g, z danym stopniem nasycenia pozostalymi krawedziami (w %)
  // oraz szansa na zwrot w tyl (w %)
	FOR(a,d,g-1) w2(a+1, a);
	FOR(a,d,g) FOR(b,d,a-1) 
		if (random()%100 < nasycenie) {
			if (random()%100 < zwrot) w1(a, b); else w1(b, a);
		} 	
}

void make_test6() {
	// sredni graf 1/2 pelny, rozpiety na lancuchu, jeden most
	int n1 = 250; n = 2*n1; 
	component(1, n1, 100, 50);
	component(n1+1, n, 100, 50);
	w2(n1, n1+1);
}

void make_test7() {
	// jak test6, ale 3 skladowe 
	int n1 = 250; n=3*n1; 
	component(1, n1, 100, 99);
	component(n1+1, 2*n1, 100, 99);
	component(2*n1+1, n, 100, 50);
	w2(n1, n1+1);
	w2(2*n1, 2*n1+1);
}

void make_test8() {
	// jak test7, ale 4 skladowe, z jednym pewnym mostem
	int n1 = 250; n=4*n1; 
	component(1, n1, 100, 99);
	component(n1+1, 2*n1, 10, 99);
	component(2*n1+1, 3*n1, 100, 50);
	component(3*n1+1, n, 100, 0);
	w2(n1, n1+1);
	w2(2*n1, 2*n1+1);
	w2(3*n1, 3*n1+1);
	w2(n1+10, n-1);
}

void make_test9() {
	// tym razem bedzie wiecej skladowych, ale mniejszych, i ustawione w drzewo sa
	int n1 = 100, d = 10; n = n1*d;
	FOR(i, 1, d) {
		component(n1*(i-1)+1, n1*i, 100, d*10);
		if (i>1) w2(n1*i, n1*(i/2) - i);
	}
}

void make_test10() {
	// wiecej tego
	int n1 = 100, d = 20; n = n1*d;
	FOR(i, 1, d) {
		component(n1*(i-1)+1, n1*i, 100, d*10);
		if (i>1) w2(n1*i, n1*(i/2) - i);
	}

}

void make_test11() {
	// tylko linia
	n = 2000;
	component(1, n, 0, 0);
}

void make_test12() {
	// lancuch z linkami jako sciek
	n = 2000; int n2=2*n/3;
	
	FOR(a,1,n2) FOR(b,a+1,n2) w1(a,b);
	FOR(a,3,n2) if (a%2) w1(a,a-2); w1(n2,n2-1);
	
	component(n2, n, 0, 0);
	
//	FOR(a,1,n) FOR(b,a+1,n) w1(a,b);
//	FOR(a,3,n) if (a%2) w1(a,a-2);	w1(n,n-1);
		
}

void make_test13() {
	// half wypas
	n = 1500; int n2 = 2*n/3;
	component(1, n2, 100, 100);
	FOR(a,2,n2) e[a-1][a] = false; 
	w2(1,n2);
	component(n2, n, 0, 0);
}

void make_test14() {
	// reversed half wypas
	n = 1500; int n2 = n/3;
	component(1, n2, 0, 100);	
	component(n2, n, 100, 0);
	FOR(a,n2,n-1) e[a+1][a] = false; 
	w2(n,n2);
}


void generate(int nr) {
        char name[30];
        sprintf(name, "c%d.in", nr);
        out = new ofstream(name);
        srandom(7219+nr);
        if (nr==0) make_test0();
        if (nr==1) make_test1();
        if (nr==2) make_test2();
        if (nr==3) make_test3();
        if (nr==4) make_test4();
        if (nr==5) make_test5();
        if (nr==6) make_test6();
        if (nr==7) make_test7();
        if (nr==8) make_test8();
        if (nr==9) make_test9();
        if (nr==10) make_test10();
        if (nr==11) make_test11();
        if (nr==12) make_test12();
        if (nr==13) make_test13();
        if (nr==14) make_test14();

        if (!check_connected()) cerr << "warning: test not connected\n";
 
        write_output(nr < 13);
        delete out;  
}

int main(int argc, char* argv[]) {

        if (argc < 2)   
          for (int i = 1; i <= 14; i++)
            generate(i);
        else { 
          int nr = atoi(argv[1]);
          generate(nr);
        }

        return 0;
}
