program Rho;

{
  task:

    calculate number of rhombs of type A, B and C for given polygon

	    *
	   / \
	  * B *
	   \ /
	*---*---*
       / A / \ C \
      *---*   *---*

  note:

    program assumes input data is syntactically correct and describes
    polygon that can be properly divided

    important for termination of most methods is that
    array contains data methods expect

  observation:

      for any polygon dividable into rhombs it is possible
      to contract all rhombs of type A and C; this allows
      to count easily the remaining rhombs of type B relaying
      on the area of remaining polygon

	  *---*---*		*-*-*		  *
	 / A / \ C \	       / / \ \		 / \
	*---* B *---*	      *-* B *-*		* B *
       / \ C \ / \ C \	     / \ \ / \ \       / \ / \
      * B *---* B *---* --> * B *-* B *-* --> * B * B *
       \ / A / \ / A /	     \ / / \ / /       \ / \ /
	*---* B *---*	      *-* B *-*		* B *
	 \ C \ / A /	       \ \ / /		 \ /
	  *---*---*		*-*-*		  *

      contracting A and B allows to calculate number of C-s
      contracting B and C allows to calculate number of A-s

  algorithm for counting rhombs of given type:

    for type in [A, B, C] do:
    (1) remove elements that do not participate in given rhomb
    (2) contract any consecutive elements with opposite directions
    (3) number of rhombs corresponds to area of remaining polygon
}

const
  { constraint on number of polygon sides }
  MAX = 50000;

type
  { answer }
  Answer = record
    a	:Longint;
    b	:Longint;
    c	:Longint;
  end;

  { polygon side }
  Element = record
    dir :Byte;
    cnt :Longint;
  end;

  { vertex }
  Point = record
    x :Double;
    y :Double;
  end;

  { edge }
  Side = record
    p :Point;
    q :Point;
  end;

  { polygon }
  Elements = array[1..MAX] of Element;

  { border }
  Sides = array[1..MAX] of Side;

  { for calculating area }
  Vector = array[1..6, 1..2] of Longint;

const
  { for calculating number of rhombs of type A (without [1, 4]) }
  VEC_A : Vector = (( 0, 0), ( 1, 0), ( 0,-1), ( 0, 0), (-1, 0), ( 0, 1));

  { for calculating number of rhombs of type B (without [3, 6]) }
  VEC_B : Vector = (( 1, 0), ( 0,-1), ( 0, 0), (-1, 0), ( 0, 1), ( 0, 0));

  { for calculating number of rhombs of type C (without [2, 5]) }
  VEC_C : Vector = (( 1, 0), ( 0, 0), ( 0,-1), (-1, 0), ( 0, 0), ( 0, 1));

{ cast to space of points with respect to v }
procedure Cast(v :Vector; var a :Elements; c :Longint; var b :Sides);
var i :Longint; p, q :Point;
begin
  if (c > 1) then begin
    q.x := 0;
    q.y := 0;
    for i := 1 to c do begin
      p.x := q.x;
      p.y := q.y;
      q.x := p.x + a[i].Cnt*v[a[i].Dir, 1];
      q.y := p.y + a[i].Cnt*v[a[i].Dir, 2];
      b[i].p := p;
      b[i].q := q;
    end;
  end;
end;

{ simple algoritm to calculate area of polygon }
function CalculateArea(var b :Sides; c :Longint) :Double;
var i :Longint; rs :Double;
begin
  rs := 0;
  if (c > 1) then
    for i := 1 to c-1 do
      rs := rs + (b[i].p.x*b[i].q.y - b[i].p.y*b[i].q.x);
  CalculateArea := abs(rs)/2;
end;

{ read polygon elements from input file into array }
procedure ReadInput(var a :Elements; var c :Longint);
var i, j, k :Longint;
begin
  Readln(c);
  if (c > 0) then
    for i := 1 to c do begin
      Readln(j, k);
      a[i].Dir := j;
      a[i].Cnt := k;
    end;
end;

{ polygon can be divided into respective number of rhombs }
procedure WriteAnswer(a :Answer);
begin
  Writeln(a.a, ' ', a.b, ' ', a.c);
end;

var
  len :Longint;
  inp :Elements;

  pts :Sides;

  anw :Answer;

begin
  // read input file
  ReadInput(inp, len);

  // count rhombs of type A
  Cast(VEC_A, inp, len, pts);

  anw.a := Round(CalculateArea(pts, len));

  // count rhombs of type B
  Cast(VEC_B, inp, len, pts);

  anw.b := Round(CalculateArea(pts, len));

  // count rhombs of type C
  Cast(VEC_C, inp, len, pts);

  anw.c := Round(CalculateArea(pts, len));

  // output answer
  WriteAnswer(anw);
end.
