{
------------------------------------------------

  CEPC 2002 Contest
  Solution for the problem "Timetable"
  Written by Lukasz Kowalik, Warsaw Univeristy

------------------------------------------------

Solution:
---------
We apply dynamic programming. For each connection we compute the 
earliest possible arrival to city N when we use this connection.
We process the connections in order of decreasing arrival time.

The time complexity is O(m + k); k = 24*60; m = # of connections.
}

const
  MAX_N = 100000;
  MAX_CON = 1000000;

type
  TTime = 0..24*60 - 1;

  TConnection =
    record
      Dep, Arr : TTime; {departure, arrival times}
      ArrToN : TTime;   {earliest arrival to city n using this connection}
      Src : LongInt;    {start city number}
      Dest : LongInt;   {destination city number}
      Optimal : Boolean;
    end;

  PConnection = ^TConnection;
  TConnections = array[1..MAX_CON] of PConnection;
  PConnections = ^TConnections;

  CityTimetable =
    record
      Con : PConnections; {array of (direct) connections. Sorted}
      ConNum : LongInt;   {number of (direct) connections}
    end;

var
  Timetable : array[1..MAX_N] of CityTimetable;
  Arrivals, Departures : array [TTime] of PConnections;
  CntArr, CntDep : array [TTime] of Integer;
  n : LongInt;

function ReadTime : LongInt;
var
  hh, mm : LongInt;
  ch1, ch2 : Char;
begin
  Read (ch1, ch2);
  hh := 10 * (Ord (ch1) - Ord ('0')) + (Ord (ch2) - Ord ('0'));
  Read (ch1); {:}
  Read (ch1, ch2);
  mm := 10 * (Ord (ch1) - Ord ('0')) + (Ord (ch2) - Ord ('0'));
  ReadTime := 60 * hh + mm;
end;

procedure ReadInput;
var
  i, j : LongInt;
  ch : char;
begin
  for i := Low (TTime) to High (TTime) do
  begin
    CntArr [i] := 0;
    CntDep [i] := 0;
  end;

  ReadLn (n);
  for i := 1 to n do
  with TimeTable [i] do
  begin
    ReadLn (ConNum);
    GetMem (Con, ConNum * SizeOf (PConnection));
    for j := 1 to ConNum do
    begin
      New (Con^ [j]);
      with Con^ [j]^ do
      begin
        Dep := ReadTime;
        Read (ch); {space}
        Arr := ReadTime;
        ReadLn (Dest);
        
        Src := i;
        Optimal := True;
        
        Inc (CntDep [Dep]);
        Inc (CntArr [Arr]);
      end;
    end;
  end;
  
  {Allocating memory for sorted arrivals and departures}
  for i := Low (TTime) to High (TTime) do
  begin
    GetMem (Arrivals [i], CntArr [i] * SizeOf (PConnection));
    GetMem (Departures [i], CntDep [i] * SizeOf (PConnection));
    CntArr [i] := 0;
    CntDep [i] := 0;
  end;
  
  {bucket sorting arrivals and departures}
  for i := 1 to n do
    with Timetable [i] do
      for j := 1 to ConNum do
        with Con^ [j]^ do
        begin
          Inc (CntDep [Dep]);
          Departures [Dep]^ [CntDep [Dep]] := Con^ [j];
        
          Inc (CntArr [Arr]);
          Arrivals [Arr]^ [CntArr [Arr]] := Con^ [j];
        end;  
end;

procedure Process;
var
  i, j  : LongInt;
  Earliest : array [1..MAX_N] of 0..24*60;
begin
  for i := 1 to n - 1 do Earliest [i] := 24*60;
  
  for i := High (TTime) downto Low (TTime) do
  begin
    {Updating table Earliest...}

    Earliest [n] := i;
    
    for j := 1 to CntDep [i] do
      with Departures [i]^ [j]^ do
        if Earliest [Src] > ArrToN then
          Earliest [Src] := ArrToN;

    {Earliest [c] = earliest arrival to city N when we start 
                    from city c at time i.}
          
    {Updating ArrToN for connections arriving at time i.}      
    for j := 1 to CntArr [i] do
      with Arrivals [i]^ [j]^ do
        ArrToN := Earliest [Dest];      

  end;
end;

procedure WriteTime (T : LongInt);
begin
  if T div 60 < 10 then
    Write ('0');
  Write (T div 60, ':');

  if T mod 60 < 10 then
    Write ('0');
  Write (T mod 60);
end;


procedure WriteOutput;
var
  i, j : LongInt;
begin
  {Removing not optimal connections from city 1...}
  i := 0;
  with Timetable [1] do
    for j := 1 to ConNum do
      if (Con^ [j]^.ArrToN < 24 * 60) and
         not (
         (i > 0) and
         (Con^ [i]^.Dep = Con^ [j]^.Dep) and
         (Con^ [i]^.ArrToN <= Con^ [j]^.ArrToN)) then
      begin        
        while (i > 0) and
              (Con^ [i]^.ArrToN >= Con^ [j]^.ArrToN) do
          i := i - 1;

        i := i + 1;
        Con^ [i] := Con^[j];
      end; 

  {Writing connections (sorted and optimal !)}
  WriteLn (i);
  with Timetable [1] do
    for j := 1 to i do
      begin
        WriteTime (Con^ [j]^.Dep);
        Write (' ');
        WriteTime (Con^ [j]^.ArrToN);
        WriteLn;
      end;

end;

begin
  ReadInput;
  Process;
  WriteOutput;
end.